{
  description = "Forgejo CI Runners";

  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";
    srvos.url = "github:numtide/srvos";
    disko.url = "github:nix-community/disko";
    # sops-nix - secrets with mozilla sops
    # https://github.com/Mic92/sops-nix
    sops-nix = {
      url = "github:Mic92/sops-nix";
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  nixConfig = {
    extra-substituters = [
      "https://nix-community.cachix.org"
      "https://hsndev.cachix.org"
    ];
    extra-trusted-public-keys = [
      "nix-community.cachix.org-1:mB9FSh9qf2dCimDSUo8Zy7bkq5CX+/rkCWyvRCYg3Fs="
      "hsndev.cachix.org-1:vN1/XGBZtMLnTFYDmTLDrullgZHSUYY3Kqt+Yg/C+tE="
    ];
  };

  outputs = { self, sops-nix, nixpkgs, srvos, disko, ... }@inputs:
  let
    linuxMachineName = "linux";
    sshPubKey = "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIBsUe5YF5z8vGcEYtQX7AAiw2rJygGf2l7xxr8nZZa7w";
    lib = nixpkgs.lib;
    inherit (self) outputs;
    in {
      nixosConfigurations = 
      {
        "aarch64-linux" = lib.nixosSystem {
        system = "aarch64-linux";
        specialArgs = {inherit inputs outputs;};
        modules = [
          sops-nix.nixosModules.sops
          srvos.nixosModules.hardware-hetzner-cloud
          srvos.nixosModules.server
          srvos.nixosModules.mixins-systemd-boot
          disko.nixosModules.disko
          ./agents/linux.nix
          (import ./disko-hetzner-cloud.nix { disks = [ "/dev/sda" ]; })
          {
            boot.loader.efi.canTouchEfiVariables = true;
            networking.hostName = "aarch64-linux";
            users.users.root.openssh.authorizedKeys.keys = [ sshPubKey ];
            services.openssh.enable = true;
            services.openssh.settings.PermitRootLogin = "without-password";
          }];
        };
      };
  }; 
}
